WireGuardFlutterLinux class

Inheritance

Constructors

WireGuardFlutterLinux()

Properties

configFile ↔ File?
getter/setter pair
filePath → Future<String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shell → Shell
final
trafficSnapshot → Stream<Map<String, dynamic>>
Stream of traffic statistics.
no setteroverride
tunnelName ↔ String?
getter/setter pair
vpnStageSnapshot → Stream<VpnStage>
Stream of VPN stage changes.
no setteroverride

Methods

checkVpnPermission() → Future<bool>
Checks for VPN permission.
override
initialize({required String interfaceName, String? vpnName, String? iosAppGroup, String? extensionBundleId}) → Future<void>
Initializes the VPN engine.
override
isConnected() → Future<bool>
Checks if the VPN is currently connected.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshStage() → Future<void>
Refreshes the VPN stage/status.
override
requestMacSystemExtension(String bundleId) → Future<void>
Requests macOS system extension installation.
override
stage() → Future<VpnStage>
Gets the current VPN stage.
override
startVpn({required String serverAddress, required String wgQuickConfig, required String providerBundleIdentifier, List<String>? excludedApps, List<String>? includedApps}) → Future<void>
Starts the VPN tunnel.
override
stopVpn() → Future<void>
Stops the VPN tunnel.
override
toString() → String
A string representation of this object.
inherited
trafficStats() → Future<Map<String, dynamic>>
Gets the latest traffic statistics.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited